@@ -14,4 +14,7 @@ print(x, y)
 
 from . tools import *
 from . numeric import *
-from . concentration import *
\ No newline at end of file
+from . concentration import *
+from . interpolation import *
+from . profile import *
+from . fermidirac import *
\ No newline at end of file
